@@ -119,7 +119,10 @@ class Html(object):
             if image.startswith("data:image"):
                 image_base64.append(image)
             elif prefix is not None:
-                image_link.append(parse.urljoin(prefix, image[1:] if image.startswith("//") else image))
+                if image.startswith("//"):
+                    image_link.append(prefix.split(":")[0] + ":" + image)
+                else:
+                    image_link.append(parse.urljoin(prefix, image))
             else:
                 image_link.append(image)
         return image_link, image_base64
